==> qt-creator-1.1.0-src.zip: qt-creator-1.1.0-src/src/plugins/subversion/subversionoutputwindow.cpp <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact:  Qt Software Information (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
**************************************************************************/

#include "subversionoutputwindow.h"
#include "subversionplugin.h"

#include <QtGui/QListWidget>
#include <QtCore/QDebug>

using namespace Subversion::Internal;

SubversionOutputWindow::SubversionOutputWindow(SubversionPlugin *svnPlugin)
    : m_svnPlugin(svnPlugin)
{
    m_outputListWidget = new QListWidget;
    m_outputListWidget->setFrameStyle(QFrame::NoFrame);
    m_outputListWidget->setWindowTitle(tr("Subversion Output"));
    m_outputListWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
}

SubversionOutputWindow::~SubversionOutputWindow()
{
    delete m_outputListWidget;
}

QWidget *SubversionOutputWindow::outputWidget(QWidget *parent)
{
    m_outputListWidget->setParent(parent);
    return m_outputListWidget;
}

QString SubversionOutputWindow::name() const
{
    return tr("Subversion");
}

void SubversionOutputWindow::clearContents()
{
    m_outputListWidget->clear();
}

int SubversionOutputWindow::priorityInStatusBar() const
{
    return -1;
}

void SubversionOutputWindow::visibilityChanged(bool b)
{
    if (b)
        m_outputListWidget->setFocus();
}

void SubversionOutputWindow::append(const QString &txt, bool doPopup)
{
    const QStringList lines = txt.split(QLatin1Char('\n'));
    foreach (const QString &s, lines)
        m_outputListWidget->addItem(s);
    m_outputListWidget->scrollToBottom();

    if (doPopup)
        popup();
}

bool SubversionOutputWindow::canFocus()
{
    return false;
}

bool SubversionOutputWindow::hasFocus()
{
    return m_outputListWidget->hasFocus();
}

void SubversionOutputWindow::setFocus()
{
}

==> qt-creator-1.2.1-src.zip: qt-creator-1.2.1-src/src/plugins/subversion/subversionoutputwindow.cpp <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://www.qtsoftware.com/contact.
**
**************************************************************************/

#include "subversionoutputwindow.h"
#include "subversionplugin.h"

#include <QtGui/QListWidget>
#include <QtCore/QDebug>

using namespace Subversion::Internal;

SubversionOutputWindow::SubversionOutputWindow(SubversionPlugin *svnPlugin)
    : m_svnPlugin(svnPlugin)
{
    m_outputListWidget = new QListWidget;
    m_outputListWidget->setFrameStyle(QFrame::NoFrame);
    m_outputListWidget->setWindowTitle(tr("Subversion Output"));
    m_outputListWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
}

SubversionOutputWindow::~SubversionOutputWindow()
{
    delete m_outputListWidget;
}

QWidget *SubversionOutputWindow::outputWidget(QWidget *parent)
{
    m_outputListWidget->setParent(parent);
    return m_outputListWidget;
}

QString SubversionOutputWindow::name() const
{
    return tr("Subversion");
}

void SubversionOutputWindow::clearContents()
{
    m_outputListWidget->clear();
}

int SubversionOutputWindow::priorityInStatusBar() const
{
    return -1;
}

void SubversionOutputWindow::visibilityChanged(bool b)
{
    if (b)
        m_outputListWidget->setFocus();
}

void SubversionOutputWindow::append(const QString &txt, bool doPopup)
{
    const QStringList lines = txt.split(QLatin1Char('\n'));
    foreach (const QString &s, lines)
        m_outputListWidget->addItem(s);
    m_outputListWidget->scrollToBottom();

    if (doPopup)
        popup();
}

bool SubversionOutputWindow::canFocus()
{
    return false;
}

bool SubversionOutputWindow::hasFocus()
{
    return m_outputListWidget->hasFocus();
}

void SubversionOutputWindow::setFocus()
{
}

bool SubversionOutputWindow::canNext()
{
    return false;
}

bool SubversionOutputWindow::canPrevious()
{
    return false;
}

void SubversionOutputWindow::goToNext()
{

}

void SubversionOutputWindow::goToPrev()
{

}

bool SubversionOutputWindow::canNavigate()
{
    return false;
}
